Introduction
============

.. include:: ../../README.rst

.. toctree::
   :hidden:

   self

Documentation
=============

.. toctree::
   :maxdepth: 3

   api/slotted

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`